From d4f7ce4de50d01b1d3f0e8d43884dafe86439769 Mon Sep 17 00:00:00 2001
From: jconway2 <jconway2@nautilus.joeconway.com>
Date: Tue, 18 Jun 2024 13:36:39 -0400
Subject: [PATCH] Add governance directory page

Create a new governance directory page which centralizes access to the
various existing pages for project governance teams and committees. In
passing, also move some content from the wiki to their own pg.o pages
(committers, sysadmins), and create non-existing pages (contributors
committee).

There are undoubtedly some missed opportunities here for general
improvement as well as other unmentioned governance groups, but this is
a good start.
---
 pgweb/util/contexts.py                        |  2 +
 templates/index.html                          |  1 +
 templates/pages/about/governance.html         | 75 ++++++++++++++
 .../pages/about/governance/contributors.html  | 36 +++++++
 .../pages/about/governance/sysadmin.html      | 37 +++++++
 templates/pages/about/policies.html           |  1 +
 .../pages/about/policies/contributors.html    | 90 +++++++++++++++++
 templates/pages/developer/committers.html     | 98 +++++++++++++++++++
 8 files changed, 340 insertions(+)
 create mode 100644 templates/pages/about/governance.html
 create mode 100644 templates/pages/about/governance/contributors.html
 create mode 100644 templates/pages/about/governance/sysadmin.html
 create mode 100644 templates/pages/about/policies/contributors.html
 create mode 100644 templates/pages/developer/committers.html

diff --git a/pgweb/util/contexts.py b/pgweb/util/contexts.py
index 7d13862f..35dc384a 100644
--- a/pgweb/util/contexts.py
+++ b/pgweb/util/contexts.py
@@ -6,6 +6,7 @@ from django.conf import settings
 sitenav = {
     'about': [
         {'title': 'About', 'link': '/about/'},
+        {'title': 'Governance', 'link': '/about/governance/'},
         {'title': 'Policies', 'link': '/about/policies/'},
         {'title': 'Feature Matrix', 'link': '/about/featurematrix/'},
         {'title': 'Donate', 'link': '/about/donate/'},
@@ -54,6 +55,7 @@ sitenav = {
     'developer': [
         {'title': 'Developers', 'link': '/developer/'},
         {'title': 'Core Team', 'link': '/developer/core/'},
+        {'title': 'Committers', 'link': '/developer/committers/'},
         {'title': 'Roadmap', 'link': '/developer/roadmap/'},
         {'title': 'Coding', 'link': '/developer/coding/'},
         {'title': 'CommitFests', 'link': 'https://commitfest.postgresql.org'},
diff --git a/templates/index.html b/templates/index.html
index fafdf862..2d5c55fd 100644
--- a/templates/index.html
+++ b/templates/index.html
@@ -40,6 +40,7 @@
       </div>
       <a href="/about/" title="Learn More"><button type="button" class="btn btn-center btn-primary btn-inline-block">Learn More</button></a>
       <a href="/about/featurematrix/" title="Feature Matrix"><button type="button" class="btn btn-center btn-primary btn-inline-block">Feature Matrix</button></a>
+      <a href="/about/governance/" title="Governance"><button type="button" class="btn btn-center btn-primary btn-inline-block">Governance</button></a>
     </div>
     <!-- END Feature -->
 
diff --git a/templates/pages/about/governance.html b/templates/pages/about/governance.html
new file mode 100644
index 00000000..b838a3c5
--- /dev/null
+++ b/templates/pages/about/governance.html
@@ -0,0 +1,75 @@
+{%extends "base/page.html"%}
+{%block title%}Governance{%endblock%}
+
+{%block contents%}
+<h1>Project Governance Directory<i class="fa fa-users"></i></h1>
+<p>
+This page lists links to pages for the various teams and committees that
+comprise the governance hierarchy of the project. Please see the individual
+linked pages for more information about each group, including membership
+and charter.
+</p>
+
+<h2>Core Team</h2>
+<p>
+  The <a href="/developer/core/">PostgreSQL Core Team</a>
+  (Core) is the central arbiter of PostgreSQL project
+  <a href="/about/policies/">policy</a> and governance.
+</p>
+
+<h2>Sysadmin Team</h2>
+<p>
+  The <a href="/about/governance/sysadmin/">PostgreSQL Sysadmin Team</a>
+  (PGInfra) runs all of the postgresql.org infrastructure. This includes
+  a wide variety of public and non-public services.
+</p>
+
+<h2>Committers</h2>
+<p>
+  The <a href="/developer/committers/">PostgreSQL Committers</a>
+  are the people with access to push to the
+  <a href="https://git.postgresql.org/gitweb/?p=postgresql.git">git repository</a>.
+</p>
+
+<h2>Security Team</h2>
+<p>
+  The <a href="/support/security/">PostgreSQL Security Team</a>
+  presides over the reporting and fixing of vulnerabilities related
+  to PostgreSQL and closely related projects. For security vulnerabilities
+  in PostgreSQL or any of the installers linked from the
+  <a href="/download/">PostgreSQL download page</a>, please email
+  <a href="mailto:security@postgresql.org">security@postgresql.org</a>.
+  For reporting non-security bugs, please visit the
+  <a href="/account/submitbug/">Report a Bug</a> page.
+  If you are unsure if an issue is a security vulnerability, please err on the
+  side of caution and email
+  <a href="mailto:security@postgresql.org">security@postgresql.org</a>.
+</p>
+
+<h2>Code of Conduct Committee</h2>
+<p>
+  The <a href="/about/policies/coc_committee/">Code of Conduct Committee</a>
+  are the people who receive and investigate all complaints related to the
+  <a href="/about/policies/coc/">PostgreSQL Code of Conduct</a>.
+</p>
+
+<h2>Contributors Committee</h2>
+<p>
+  The <a href="/about/governance/contributors/">Contributors Committee</a>
+  curates the <a href="/community/contributors/">Contributor Profiles</a>
+  page.
+</p>
+
+<h2>Sponsors Committee</h2>
+<p>
+  The <a href="/about/policies/sponsorship/">Sponsors Committee</a>
+  maintains the <a href="/about/sponsors/">Sponsors</a> pages.
+</p>
+
+<h2>Non Profit Organizations</h2>
+<p>
+  Several <a href="/about/donate/">Non Profit Organizations</a>
+  serve the PostgreSQL Project in a variety of ways.
+</p>
+
+{%endblock%}
diff --git a/templates/pages/about/governance/contributors.html b/templates/pages/about/governance/contributors.html
new file mode 100644
index 00000000..a7fd55a7
--- /dev/null
+++ b/templates/pages/about/governance/contributors.html
@@ -0,0 +1,36 @@
+{%extends "base/page.html"%}
+{%block title%}Contributors Committee{%endblock%}
+{%block contents%}
+
+<h1>Contributors Committee <i class="fa fa-users"></i></h1>
+
+<p>
+  All Contributor recognition is curated by the Contributor Committee,
+  who decides on the status of each Contributor, or potential Contributor,
+  on an individual basis. Decisions are made in accordance with the
+  <a href="/about/policies/contributors/">Recognized Contributors</a> policy.
+  The decision of the committee is final unless overridden by the
+  Core Team. The Contributor Committee strives to meet regularly to
+  discuss the current pool of candidates. The
+  <a href="/community/contributors/">Contributor Profiles</a> page is
+  updated promptly after any decisions are made with respect to additions
+  or changes.
+</p>
+
+<p>
+  The current members are:
+</p>
+<ul>
+  <li>Christoph Berg</li>
+  <li>Joe Conway</li>
+  <li>Melanie Plageman</li>
+</ul>
+
+<p>
+  The size and membership of the Committee is self determined,
+  but ratified by a simple majority vote of the Core Team. Generally
+  the goal is that there be a minimum of three people, with no single
+  company employing a majority of the committee membership.
+</p>
+
+{%endblock%}
diff --git a/templates/pages/about/governance/sysadmin.html b/templates/pages/about/governance/sysadmin.html
new file mode 100644
index 00000000..6e37a41a
--- /dev/null
+++ b/templates/pages/about/governance/sysadmin.html
@@ -0,0 +1,37 @@
+{%extends "base/page.html"%}
+{%block title%}Infrastructure Team{%endblock%}
+{%block contents%}
+
+<h1>Infrastructure Team <i class="fa fa-users"></i></h1>
+
+<p>
+  The Infrastructure team is responsible for running all of the
+  postgresql.org infrastructure. This includes a wide variety of
+  public and non-public services. PostgreSQL website development
+  is discussed on the
+  <a href="http://archives.postgresql.org/pgsql-www/">pgsql-www mailing list</a>.
+  Source code for the postgresql.org web site is stored in a public
+  <a href="https://git.postgresql.org/gitweb/?p=pgweb.git;a=summary">GIT repository</a>.
+</p>
+
+<h2>Infrastructure Team Members</h2>
+
+<p>
+  The following people are part of the sysadmin team running the
+  postgresql.org infrastructure.
+</p>
+<ul>
+  <li>Magnus Hagander</li>
+  <li>&Aacute;lvaro Herrera</li>
+  <li>Stefan Kaltenbrunner</li>
+  <li>Dave Page</li>
+  <li>Joe Conway</li>
+  <li>Christophe Pettus</li>
+</ul>
+
+<p>
+  In case you want to reach out to the Infrastructure team, please
+  contact us at sysadmins@lists.postgresql.org 
+</p>
+
+{%endblock%}
diff --git a/templates/pages/about/policies.html b/templates/pages/about/policies.html
index 79c39170..9cff1e4a 100644
--- a/templates/pages/about/policies.html
+++ b/templates/pages/about/policies.html
@@ -45,6 +45,7 @@
 <h2>Community Recognition Policies</h2>
 
 <ul>
+    <li><a href="/about/policies/contributors/">Recognized Contributors</a></li>
     <li><a href="/about/policies/sponsorship/">PostgreSQL Sponsorship</a></li>
     <li><a href="/about/policies/conferences/">Conferences</a></li>
     <li><a href="/about/policies/npos/">Non-Profit Organisations</a></li>
diff --git a/templates/pages/about/policies/contributors.html b/templates/pages/about/policies/contributors.html
new file mode 100644
index 00000000..d948936b
--- /dev/null
+++ b/templates/pages/about/policies/contributors.html
@@ -0,0 +1,90 @@
+{%extends "base/page.html"%}
+{%load pgfilters%}
+{%block title%}Recognized Contributors{%endblock%}
+{%block contents%}
+
+<h1>Recognized Contributors <i class="fas fa-gavel"></i></h1>
+
+<p>
+  The PostgreSQL <a href="/community/contributors/">Contributor Profiles</a> page
+  includes people who have made substantial, long-term contributions of time
+  and effort to the PostgreSQL project. One-time-only or short-term contributions
+  are not usually considered adequate for listing, unless they involve quite large
+  amounts of code and time. Financial contributions get listed on the
+  <a href="/about/sponsors/">Sponsors</a> pages, not here.
+</p>
+
+<h2>Contributors levels</h2>
+
+<h3>Current Contributors</h3>
+<p>
+  The <a href="/community/contributors/">Contributor Profiles</a> page
+  lists Core Team members and two levels of PostgreSQL Contributors:
+</p>
+<ul>
+  <li><strong>Core Team</strong> people on the
+      <a href="/developer/core/">PostgreSQL Core Team</a>
+  </li>
+  <li><strong>Major Contributors</strong> individuals that have provided
+      a sustained stream of contributions, having substantial positive
+      impact on the development of the PostgreSQL Community, over many years.
+  </li>
+  <li><strong>Contributors</strong> individuals that have provided a sustained
+       stream of notable contributions in recent years.
+  </li>
+</ul>
+
+<h3>Past Contributors</h3>
+<p>
+  This section lists people who were in the Core Team, Major Contributor,
+  or Contributor section, but have stopped contributing for an extended
+  period of time.
+</p>
+<ul>
+  <li>Hackers Emeritus - past Core Team members</li>
+  <li>Past Contributors - all past Contributors (Major or otherwise)</li>
+</ul>
+
+<h2>Types of Contributions</h2>
+
+<p>
+  Contributions to the PostgreSQL Project that may be considered by the
+  committee include, but are not limited to:
+</p>
+<ul>
+  <li>Code: Author, review, test, and/or commit patches that are pushed
+      to the primary PostgreSQL git repository, and/or to closely related
+      external projects such as PostGIS, pgjdbc, PGAdmin</li>
+  <li>Translation: user facing messages in source code, documentation</li>
+  <li>Community mailing list participation: report bugs, suggest features,
+      contribute to ongoing discussions, answer questions, list moderation</li>
+  <li>Governance of the PostgreSQL project or community recognized NPOs:
+      Core Team, NPO Board of Directors, NPO Officers, NPO Committees</li>
+  <li>Maintenance and operation of community controlled infrastructure:
+      Sysadmin Team, Web Team</li>
+  <li>Other Community recognized committee participation:
+      Security, Code of Conduct</li>
+  <li>Management of the development process and software lifecycle:
+      Commitfest managers, Release Management Team, Release Team,
+      Packagers, Buildfarm animal maintenance</li>
+  <li>Organization and execution of community recognized conferences:
+      Organizing committee, Selection Committee, Speakers, Volunteers</li>
+  <li>Open Education: PostgreSQL related Blogs, articles, uncompensated
+      training/tutorials</li>
+  <li>Open Support (in addition to community mailing lists):
+      #postgresql IRC channel, Postgres slack channel, Stack Overflow
+  </li>
+</ul>
+
+
+<h2>Committee Governance</h2>
+<p>
+  The current method of choosing who qualifies as a Contributor is via
+  simple majority vote of those on the committee. The size and membership
+  of the Committee is self determined, but ratified by a simple majority
+  vote of the Core Team. Generally the goal is that there be a minimum of
+  three people, with no single company employing a majority of the
+  committee membership.
+</p>
+
+{%endblock%}
diff --git a/templates/pages/developer/committers.html b/templates/pages/developer/committers.html
new file mode 100644
index 00000000..0492bfc6
--- /dev/null
+++ b/templates/pages/developer/committers.html
@@ -0,0 +1,98 @@
+{%extends "base/page.html"%}
+{%block title%}Committers{%endblock%}
+{%block contents%}
+
+<h1>Committers <i class="fa fa-users"></i></h1>
+
+<p>
+  This is the current list of people with access to push to the
+  <a href="https://git.postgresql.org/gitweb/?p=postgresql.git">git repository</a>.
+  For technical details on how committing works, see
+  <a href="https://wiki.postgresql.org/wiki/Committing_with_Git">Committing with Git</a>.
+  This is just a list of people who currently have access to push to git; for
+  information on current and previous contributors, see the contributor profiles
+  section of the web site.
+</p>
+
+<h2>Committers</h2>
+
+<p>
+  The names are listed here in order of first commit or when added
+  as a committer, oldest first; this isn't intended to imply anything
+  about depth of contribution.
+</p>
+<ul>
+  <li>Bruce Momjian</li>
+  <li>Tom Lane</li>
+  <li>Tatsuo Ishii</li>
+  <li>Peter Eisentraut</li>
+  <li>Joe Conway</li>
+  <li>&Aacute;lvaro Herrera</li>
+  <li>Andrew Dunstan</li>
+  <li>Magnus Hagander</li>
+  <li>Heikki Linnakangas</li>
+  <li>Robert Haas</li>
+  <li>Jeff Davis</li>
+  <li>Fujii Masao</li>
+  <li>Noah Misch</li>
+  <li>Andres Freund</li>
+  <li>Dean Rasheed</li>
+  <li>Alexander Korotkov</li>
+  <li>Amit Kapila</li>
+  <li>Tomas Vondra</li>
+  <li>Michael Paquier</li>
+  <li>Thomas Munro</li>
+  <li>Peter Geoghegan</li>
+  <li>Etsuro Fujita</li>
+  <li>David Rowley</li>
+  <li>Daniel Gustafsson</li>
+  <li>John Naylor</li>
+  <li>Nathan Bossart</li>
+  <li>Amit Langote</li>
+  <li>Masahiko Sawada</li>
+  <li>Melanie Plageman</li>
+  <li>Richard Guo</li>
+</ul>
+
+<h2>Notes on the Commit Log</h2>
+<p>
+  Hundreds of developers have successfully contributed work to PostgreSQL
+  over decades, many acting as individuals, though also many representing
+  academic institutions and both user and vendor companies. Both the "Author"
+  and "Committer" fields of such patches will reflect the committer. The actual
+  author of a patch, if different, is generally listed in the commit message;
+  reviewers or others who contributed ideas or otherwise helped with the patch
+  may also be listed. Many patches, in the form in which they are committed,
+  are the work of multiple people: original author or authors, reviewer(s),
+  and/or committer. As a result, no simple analysis of duration or depth of
+  contribution over time is possible from the commit log. The project operates
+  a system of careful peer review and even committers have their work checked
+  by other committers and the community as a whole.
+</p>
+
+<h2>New Committers and Removing Committers</h2>
+<p>
+  New committers are added approximately annually after discussions
+  and vote among the existing committers. Contributors to PostgreSQL
+  are selected to be committers based on the following loose criteria:
+</p>
+<ul>
+  <li>several years of substantial contributions to the project</li>
+  <li>multiple and continuing code contributions</li>
+  <li>responsibility for maintenance of one or more areas of the codebase</li>
+  <li>track record of reviewing and helping other contributors with their patches</li>
+  <li>high quality code contributions which require very little revision or correction for commit</li>
+  <li>demonstrated understanding of the process and criteria for patch acceptance</li>
+</ul>
+<p>
+  Generally, new committers are selected March or April and announced on the
+  <a href="/list/pgsql-hackers/">Hackers mailing list</a>.
+</p>
+
+<p>
+  Committers who have become inactive and have not contributed significantly
+  to the PostgreSQL project in several years are removed as committers. Again,
+  the review process for this is approximately annual. 
+</p>
+
+{%endblock%}
-- 
2.34.1

